#
# spec file for package iptraf-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iptraf-ng
Version:        1.2.2
Release:        1.2
Summary:        TCP/IP Network Monitor
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/iptraf-ng/iptraf-ng/
Source:         https://github.com/iptraf-ng/iptraf-ng/archive/v%version.tar.gz
BuildRequires:  automake
BuildRequires:  ncurses-devel
BuildRequires:  xz
Obsoletes:      iptraf < 4
# Just pick a number that is >3
Provides:       iptraf = 4

%description
IPTraf-ng is a console-based network statistics utility. It gathers a
variety of information such as TCP connection packet and byte counts,
interface statistics and activity indicators, TCP/UDP traffic
breakdowns, and LAN station packet and byte counts.

%prep
%autosetup -n %name-%version -p1

%build
%{?make_build}%{!?make_build:make %{?_smp_mflags}} CFLAGS="%optflags -D_GNU_SOURCE"

%install
%make_install prefix="%_prefix" V=1
b="%buildroot"
install -dm 0755 "$b/%_localstatedir/lib/iptraf-ng"
ln -s iptraf-ng "$b/%_sbindir/iptraf"
ln -s iptraf-ng.8 "$b/%_mandir/man8/iptraf.8"

%files
%_sbindir/iptraf*
%_mandir/man8/iptraf*
%_localstatedir/lib/iptraf-ng

%changelog
* Thu Nov 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.2
  * serv.c: validate loading/saving/entry of port ranges
  * limit interface name lengths to IFNAMSIZ [CVE-2024-52949]
* Wed Nov 11 2020 Martin Wilck <mwilck@suse.com>
- Fix build error on SLE12 (%%make_build not defined)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.1:
  * Makefile: protect mandatory compile flags
  * packet capture: don't reuse socket for multiple receive functions
  * TPACKET_V[23]: continue even if mlock() fails
- remove 0001-Revert-TPACKET_V3-mlock-mmap-ed-address-space-into-R.patch:
  fixed differently upstream
* Wed Jun 10 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * A set of minor bugfixes.
  * Fix CPU hogging if the interface gets removed [rhbz#1572750]
- Drop iptraf-ng-1.1.4-fix-Floating-point-exception-in-tcplog_flowra.patch,
  build-use-wide-version-of-lpanel-when-needed.patch,
  0001-ifstats-make-sort-by-ifname-the-only-mode-of-operati.patch
  (merged)
- Add 0001-Revert-TPACKET_V3-mlock-mmap-ed-address-space-into-R.patch
* Sun Jan 12 2020 Jan Engelhardt <jengelh@inai.de>
- Employ new homepage URLs.
- Rename the SRPM from iptraf to iptraf-ng. Effectively no change
  for the produced BRPMs.
- Add 0001-ifstats-make-sort-by-ifname-the-only-mode-of-operati.patch
  from upstream.
* Wed Aug 12 2015 jslaby@suse.com
- add build-use-wide-version-of-lpanel-when-needed.patch (bnc#940207)
* Wed Sep 18 2013 andreas.stieger@gmx.de
- fix "Floating point exception" in tcplog_flowrate_msg(), adds
  iptraf-ng-1.1.4-fix-Floating-point-exception-in-tcplog_flowra.patch
  from Fedora [bnc#841156]
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 1.1.4
  * update all rates not only the visible ones
  * add 802.1ad / 802.1ah / QinQ ethertypes
- Removed 0001-build-prefer-ncurses6-and-wide.patch
  (merged upstream)
* Thu Mar 28 2013 jengelh@inai.de
- Update to new git snapshot 1.1.3.1+git49
  * remove TokenRing and ISDN support
  * 802.1ad and QinQ VLAN handling
  * restore functionality of iptraf -B (bnc#812080)
- Remove iptraf-ng-1.1.3.1-kernel-v3.5-kill-off-token-ring-support.patch
  (merged upstream)
- Add 0001-build-prefer-ncurses6-and-wide.patch
- Depend on 3.1 headers (source uses ETH_P_QINQ1)
* Sun Oct  7 2012 andreas.stieger@gmx.de
- iptraf-ng-1.1.3.1-kernel-v3.5-kill-off-token-ring-support.patch
  to remove TokenRing support which was removed in Linux 3.5
- move to pristine upstream tarball
* Thu May 31 2012 jengelh@inai.de
- Update to new upstream release 1.1.3.1
  * support SIT tunnels
  * fix checksumming for odd-sized IPv4 packets
- iptraf-1.0.2-segfault.patch rendered obsolete by commit b3eec3f
* Thu May 10 2012 jengelh@inai.de
- Update to new upstream release 1.1.2
  * New RFC1071-based IP checksum implementation
  * Various fixes for IPv6 port statistics and byte counting,
  interfaces with long names, PPP handling
  * Make capturing on TUN interfaces work
  * Support GRE tunnels
* Thu Dec 15 2011 puzel@suse.com
- install /var/lib/iptraf-ng directory (bnc#736900)
- fix executing rvnamed daemon (bnc#737032)
  - add fix-calling-rvnamed.patch
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep  1 2011 vcizek@suse.com
- fixed segfault caused by off-by-one allocation error (bnc#711726)
* Wed Apr 20 2011 jengelh@medozas.de
- Name the binary package iptraf-ng
* Mon Apr  4 2011 jengelh@medozas.de
- Run spec-beautifier
* Mon Apr  4 2011 puzel@novell.com
- switch to iptraf-ng (thanks jengelh@medozas.de)
- drop all patches (merged upstream)
* Sat Feb 13 2010 rguenther@suse.de
- fix harmless buffer-overflow to fix build with GCC 4.5
* Wed Nov 11 2009 puzel@suse.cz
- iptraf-3.0.0-fix-promisc-crash.patch (bnc#548485)
* Mon Oct  6 2008 prusnak@suse.cz
- fixed wrong comparison of file descriptor (fd.patch) [bnc#431904]
* Thu Apr 10 2008 prusnak@suse.cz
- alter package after ncurses packaging change
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Tue Nov 28 2006 prusnak@suse.cz
- fixed line drawing in console (lines.patch) [#223678]
* Wed Aug 30 2006 lmichnovic@suse.cz
- fixed uninitialized variable (uninitialized.patch) [#197715]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 24 2005 pnemec@suse.cz
- fix strict aliasing errors.
- added patch -strict-aliasing.patch
* Wed Nov 23 2005 pnemec@suse.cz
- updated to new version 3.0.0
- fixed headers and support/Makefile to build
* Thu Sep  8 2005 pnemec@suse.cz
- fixed file permisions bug [#114849]
* Mon Aug 29 2005 postadal@suse.cz
- added support for ni, br, tap, dummy and vmnet devices
  [#105545] (dev.diff)
* Fri Jun 17 2005 meissner@suse.de
- use RPM_OPT_FLAGS in support/ too.
* Mon Jun 13 2005 kukuk@suse.de
- Avoid using kernel headers if there are glibc variants
* Wed Apr 13 2005 arvin@suse.de
- added support for modem device
* Tue Jan 18 2005 postadal@suse.cz
- added support for dsl device [#49721, #49882]
* Thu Sep 30 2004 postadal@suse.cz
- allow normal user use iptraf if the s-bit is set [#46231] (euid-fix.diff)
* Fri Sep  3 2004 kukuk@suse.de
- Fix compiling with new glibc headers
* Tue Apr 20 2004 postadal@suse.cz
- set iptraf and rvnamed permission to 0755
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jan 13 2003 postadal@suse.cz
- updated to version 2.7.0
  * added support for Token Ring, sbni long-range modem, Free s/WAN IPSec
    logical, DVB (sm2*, sm3*, penta*), wireless LAN (wlan*, wvlan*) interfaces
  * a lot of fixes
* Mon Dec 17 2001 cihlar@suse.cz
- added /var/run/iptraf to package
- fixed man pages
* Thu Nov 29 2001 cihlar@suse.cz
- update to version 2.5.0:
  * many fixes and improvements
* Wed Jul  4 2001 cihlar@suse.cz
- update to version 2.4.0
- added BuildRoot
- clean up spec file
* Thu Jan  4 2001 ray@suse.de
- update to version 2.3.1
* Tue Feb 15 2000 aj@suse.de
- Fix CFLAGS.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 25 1999 uli@suse.de
- added CFLAGS for PPC
* Thu Jan 21 1999 ro@suse.de
- no m486 on alpha
* Mon Sep 14 1998 ro@suse.de
- added directory /var/iptraf to filelist
* Thu Aug 20 1998 ro@suse.de
- fixed src/dirs.h (adapted to initial changes in Makefile)
- and adapted the README.rvnamed
* Sat Jun 20 1998 ray@suse.de
- new package
